@@ -115,9 +115,11 @@ def validate_single_tag(value: List[str]) -> Tuple[None, List[str]]:
     return None, value
 
 
-def validate_strip_right_slash(value: str) -> Tuple[None, str]:
-    """Strips the right slash"""
-    if value:
+def validate_url_base(value: str) -> Tuple[None, str]:
+    """Strips the right slash and adds starting slash, if not present"""
+    if value and isinstance(value, str):
+        if not value.startswith("/"):
+            value = "/" + value
         return None, value.rstrip("/")
     return None, value
 
@@ -277,6 +279,9 @@ def validate_default_if_empty(root: str, value: str, default: str) -> Tuple[None
 # Special settings
 ##############################################################################
 
+# Increase everytime we do a configuration conversion
+config_conversion_version = OptionNumber("misc", "config_conversion_version", default_val=0)
+
 # This should be here so it's initialized first when the config is read
 helpful_warnings = OptionBool("misc", "helpful_warnings", True)
 
@@ -309,8 +314,8 @@ version_check = OptionNumber("misc", "check_new_rel", 1)
 autobrowser = OptionBool("misc", "auto_browser", True)
 language = OptionStr("misc", "language", "en")
 enable_https_verification = OptionBool("misc", "enable_https_verification", True)
-cherryhost = OptionStr("misc", "host", DEF_HOST, validation=validate_host)
-cherryport = OptionStr("misc", "port", DEF_PORT)
+web_host = OptionStr("misc", "host", DEF_HOST, validation=validate_host)
+web_port = OptionStr("misc", "port", DEF_PORT)
 https_port = OptionStr("misc", "https_port")
 username = OptionStr("misc", "username")
 password = OptionPassword("misc", "password")
@@ -443,7 +448,7 @@ start_paused = OptionBool("misc", "start_paused", False)
 preserve_paused_state = OptionBool("misc", "preserve_paused_state", False)
 enable_par_cleanup = OptionBool("misc", "enable_par_cleanup", True)
 process_unpacked_par2 = OptionBool("misc", "process_unpacked_par2", True)
-enable_multipar = OptionBool("misc", "enable_multipar", True)
+disable_par2cmdline = OptionBool("misc", "disable_par2cmdline", False)
 enable_unrar = OptionBool("misc", "enable_unrar", True)
 enable_7zip = OptionBool("misc", "enable_7zip", True)
 enable_filejoin = OptionBool("misc", "enable_filejoin", True)
@@ -486,7 +491,7 @@ wait_ext_drive = OptionNumber("misc", "wait_ext_drive", 5, minval=1, maxval=60)
 max_foldername_length = OptionNumber("misc", "max_foldername_length", DEF_FOLDER_MAX, minval=20, maxval=65000)
 marker_file = OptionStr("misc", "nomedia_marker")
 ipv6_servers = OptionBool("misc", "ipv6_servers", True)
-url_base = OptionStr("misc", "url_base", "/sabnzbd", validation=validate_strip_right_slash)
+url_base = OptionStr("misc", "url_base", "", validation=validate_url_base)
 host_whitelist = OptionList("misc", "host_whitelist", validation=all_lowercase)
 local_ranges = OptionList("misc", "local_ranges", protect=True)
 max_url_retries = OptionNumber("misc", "max_url_retries", 10, minval=1)
@@ -691,7 +696,9 @@ def set_root_folders2():
 ##############################################################################
 def new_limit():
     """Callback for article cache changes"""
-    sabnzbd.ArticleCache.new_limit(cache_limit.get_int())
+    if sabnzbd.__INITIALIZED__:
+        # Only update after full startup
+        sabnzbd.ArticleCache.new_limit(cache_limit.get_int())
 
 
 def guard_restart():
@@ -732,3 +739,63 @@ def guard_language():
 def guard_https_ver():
     """Callback for change of https verification"""
     sabnzbd.misc.set_https_verification(enable_https_verification())
+
+
+##############################################################################
+# Conversions
+##############################################################################
+
+
+def config_conversions():
+    """Update sections of the config, only once"""
+    # Basic old conversions
+    if config_conversion_version() < 1:
+        logging.info("Config conversion set 1")
+        # Convert auto-sort
+        if auto_sort() == "0":
+            auto_sort.set("")
+        elif auto_sort() == "1":
+            auto_sort.set("avg_age asc")
+
+        # Convert old series/date/movie sorters
+        if not sorters_converted():
+            sabnzbd.misc.convert_sorter_settings()
+            sorters_converted.set(True)
+
+        # Convert duplicate settings
+        if no_series_dupes():
+            no_smart_dupes.set(no_series_dupes())
+            no_series_dupes.set(0)
+
+        # Convert history retention setting
+        if history_retention():
+            sabnzbd.misc.convert_history_retention()
+            history_retention.set("")
+
+        # Add hostname to the whitelist
+        if not host_whitelist():
+            host_whitelist.set(socket.gethostname())
+
+        # Set cache limit for new users
+        if not cache_limit():
+            cache_limit.set(sabnzbd.misc.get_cache_limit())
+
+        # Done
+        config_conversion_version.set(1)
+
+    # url_base conversion
+    if config_conversion_version() < 2:
+        # We did not end up applying this conversion, so we skip this conversion_version
+        logging.info("Config conversion set 2")
+        config_conversion_version.set(2)
+
+    # Switch to par2cmdline-turbo on Windows
+    if config_conversion_version() < 3:
+        logging.info("Config conversion set 3")
+        if sabnzbd.WIN32 and par_option():
+            # Just empty it, so we don't pass the wrong parameters
+            logging.warning(T("The par2 application was switched, any custom par2 parameters were removed"))
+            par_option.set("")
+
+        # Done
+        config_conversion_version.set(3)
